﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.DesktopEdition;

namespace EDPCalculation
{
    public partial class Form1 : Form
    {
        ManagedProj4Projection _proj = new ManagedProj4Projection();
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            #region MyRegion
            _proj.InternalProjectionParametersString = ManagedProj4Projection.GetEpsgParametersString(4326);
            _proj.ExternalProjectionParametersString = ManagedProj4Projection.GetEsriParametersString(54004);
            _proj.Open();
            LoadDefaultMap();

            wfMap.ExtentOverlay.MouseWheelMode = MapMouseWheelMode.Zooming;
            InMemoryFeatureLayer im1 = new InMemoryFeatureLayer();
            im1.FeatureSource.Projection = _proj;
            im1.Open();
            im1.Columns.Add(new FeatureSourceColumn("Name"));

            TextStyle ts = TextStyles.CreateSimpleTextStyle("Name", "Arial", 10, DrawingFontStyles.Bold, GeoColors.Black,15,0);
            //TextStyle ts = new TextStyle("Name", new GeoFont("Arial", 10), new GeoSolidBrush(GeoColors.Black));
            //ts.XOffsetInPixel = 15;
            //ts.FittingLineInScreen = true;
            //ts.AllowLineCarriage = true;
            //ts.ForceHorizontalLabelForLine = true;
            //ts.ForceLineCarriage = true;
            //ts.LabelAllLineParts = true;
            //ts.LeaderLineMinimumLengthInPixels = 100f;
            //ts.LeaderLineRule = LabelLeaderLinesRule.AllowLeaderLines;
            //ts.SplineType = SplineType.ForceSplining;
            //ts.SuppressPartialLabels = true;
            //ts.TextLineSegmentRatio = 100f;
            //ts.LabelPositions
            ts.BestPlacement = true;
            im1.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = ts;

            im1.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColors.Transparent), new GeoPen(GeoColors.Black), 10);
            im1.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = new LineStyle(new GeoPen(GeoColors.Black));
            im1.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            Feature ft1 = new Feature(new PointShape(10, 10));
            ft1.ColumnValues.Add("Name", "CVR");
            im1.InternalFeatures.Add(ft1);

            ft1 = new Feature(new PointShape(12, 10));
            ft1.ColumnValues.Add("Name", "MKV");
            im1.InternalFeatures.Add(ft1);

            ft1 = new Feature(new LineShape("LINESTRING(10 10,50 10)"));
            ft1.ColumnValues.Add("Name", "");
            im1.InternalFeatures.Add(ft1);

            ft1 = new Feature(new LineShape("LINESTRING(12 10,30 0)"));
            ft1.ColumnValues.Add("Name", "");
            im1.InternalFeatures.Add(ft1);

            ft1 = new Feature(new PointShape(50, 10));
            ft1.ColumnValues.Add("Name", "SUV");
            im1.InternalFeatures.Add(ft1);

            ft1 = new Feature(new PointShape(30, 0));
            ft1.ColumnValues.Add("Name", "MUV");
            im1.InternalFeatures.Add(ft1);

            LayerOverlay lo = new LayerOverlay();
            lo.Layers.Add("SampleLayer", im1);
            wfMap.Overlays.Add("SampleOverlay", lo);
            wfMap.CurrentExtent = _proj.ConvertToExternalProjection(new RectangleShape(-130, 60, 130, -60));
            wfMap.Refresh();
            #endregion
        }

        private void LoadDefaultMap()
        {
            try
            {
                wfMap.MapUnit = _proj.GetExternalGeographyUnit();
                wfMap.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.FromArgb(255, 200, 227, 255));

                ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(Application.StartupPath + @"/Data/Countries02.shp");
                worldLayer.FeatureSource.Projection = _proj;
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = new AreaStyle(new GeoPen(GeoColor.FromArgb(255, 128, 128, 64), 1F), new GeoSolidBrush(GeoColor.FromArgb(255, 239, 228, 176)));
                worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                LayerOverlay worldOverlay = new LayerOverlay();
                worldOverlay.Layers.Add("WorldLayer", worldLayer);
                wfMap.Overlays.Add("WorldOverlay", worldOverlay);
            }
            catch (Exception err)
            {
                MessageBox.Show(err.Message);
            }
        }
    }
}
